@@ -40,6 +40,7 @@ class Gui : public QWidget, public Ui::Gui {
       QSettings      *settings; 
       QString        program1, program2;
       bool           process2Started;
+      bool           aborted;
 
      private slots:
       void currentDateAndTime(); //for the current minimum date and time
@@ -47,6 +48,7 @@ class Gui : public QWidget, public Ui::Gui {
       void getProgram1();
       void getProgram2();
       void run();         //runs the process
+      void abortProcesses();       //aborts all running processes
       void output1();      //prints output into a file if loggingCheckBox is checked
       void output2();
       void errorOutput1(); //prints errorOutput into a file if loggingCheckBox is checked
