@@ -17,11 +17,13 @@
 
 #include "calendar.h"
 
-extern bool timeRunning; //variable declared in gui.cpp
+extern bool calendarClosed; //variable declared in gui.cpp
+extern bool timeRunning;    // ""
 QDate setCalendarDate;
 QDate calendarDate;
 
 Calendar::Calendar(QWidget *parent): QDialog(parent){
+
 	setupUi(this);
 
      setWindowFlags(Qt::WindowStaysOnTopHint | Qt::Window);    //always in front
@@ -29,7 +31,8 @@ Calendar::Calendar(QWidget *parent): QDialog(parent){
      calendarWidget->setMinimumDate(QDate::currentDate());
 
      connect(calendarWidget, SIGNAL(clicked(QDate)), this, SLOT(getDate(QDate)));
-     connect(buttonBox, SIGNAL(accepted()), this, SLOT(setDate()));
+     connect(buttonBox->button(QDialogButtonBox::Ok), SIGNAL(clicked(bool)), this, SLOT(setDate()));
+     connect(this, SIGNAL(rejected()), this, SLOT(close()));
 }
 
 Calendar::~Calendar(){;}
@@ -42,3 +45,17 @@ void Calendar::setDate(){
        aDateWasSet();
      }
 }
+
+void Calendar::showEvent(QShowEvent* show_){
+     calendarClosed = false;
+     starting();
+     QDialog::showEvent(show_);
+}
+
+void Calendar::closeEvent(QCloseEvent* close_){
+     if(!timeRunning){
+       calendarClosed = true;
+       finishing();
+     }
+     QDialog::closeEvent(close_);
+}
