@@ -23,6 +23,12 @@
 #include "passwd.h"
 #include "editor.h"
 
+bool prefClosed = true;
+bool calendarClosed = true;
+bool infoClosed = true;
+bool passwdClosed = true;
+bool editorClosed = true;
+
 bool timeRunning;
 bool lockMyScreen;
 extern QString fonts; //variable declared in preferences.cpp
@@ -149,36 +155,53 @@ Gui::Gui(QWidget *parent): QWidget(parent){
      connect(radio1, SIGNAL(toggled(bool)), timeEdit, SLOT(setEnabled(bool)));
      connect(radio2, SIGNAL(toggled(bool)), spin, SLOT(setEnabled(bool)));
      connect(comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(power_action(int)));
-     connect(power_actions, SIGNAL(triggered(QAction*)), this, SLOT(power(QAction*)));
      connect(ti, SIGNAL(timeout()), this, SLOT(showW())); //set window state for ti
      connect(ok, SIGNAL(clicked(bool)), this, SLOT(set())); //starts timers and time calculations
-     connect(timer, SIGNAL(timeout()), this, SLOT(updateT()));    //runs updateT() every 10 seconds
-     connect(now, SIGNAL(clicked(bool)), this, SLOT(finished()));//closes the program & starts the shutdown immediately
+     connect(timer, SIGNAL(timeout()), this, SLOT(updateT()));    //runs updateT() every second
+     connect(now, SIGNAL(clicked(bool)), this, SLOT(finished_()));//closes the program & starts the shutdown immediately
      connect(minim, SIGNAL(clicked(bool)), this, SLOT(showMinimized())); //minimizes window
      connect(TIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
        this, SLOT(iconActivated(QSystemTrayIcon::ActivationReason))); //handles systray-symbol
+     connect(power_actions, SIGNAL(triggered(QAction*)), this, SLOT(power(QAction*)));
+     connect(reset_action, SIGNAL(triggered()), this, SLOT(reset()));
+     connect(qApp, SIGNAL(aboutToQuit()), this, SLOT(beforeQuit())); //save window size / logs and unregister qshutdown
+     connect(quit_action, SIGNAL(triggered()), qApp, SLOT(quit())); //contextmenu "Quit" for the systray quits Programm
+
      connect(pref_action, SIGNAL(triggered()), pref, SLOT(show()));
      connect(pref, SIGNAL(starting()), ti, SLOT(stop()));
-     connect(pref, SIGNAL(finishing()), ti, SLOT(start())); //start the Qtimer ti if timeRunning == false
+     connect(pref, SIGNAL(finishing()), this, SLOT(warnings_on())); //start the Qtimer ti if timeRunning == false
      connect(pref, SIGNAL(changeFont()), this, SLOT(getFonts()));
-     connect(reset_action, SIGNAL(triggered()), this, SLOT(reset()));
+     connect(pref, SIGNAL(editConf()), checkPassword, SLOT(show()));  //ask for password when button was pressed at preferences
+
      connect(info_action, SIGNAL(triggered()), this, SLOT(setInfoText()));
      connect(info_action, SIGNAL(triggered()), infoBox, SLOT(show()));
      connect(infoBox, SIGNAL(starting()), ti, SLOT(stop()));
-     connect(infoBox, SIGNAL(finishing()), ti, SLOT(start()));
+     connect(infoBox, SIGNAL(finishing()), this, SLOT(warnings_on()));
+
      connect(toolButton, SIGNAL(clicked(bool)), this, SLOT(showCalendarBox()));
      connect(calendarBox, SIGNAL(aDateWasSet()), this, SLOT(setDate()));
-     connect(qApp, SIGNAL(aboutToQuit()), this, SLOT(beforeQuit())); //save window size / logs and unregister qshutdown
-     connect(quit_action, SIGNAL(triggered()), qApp, SLOT(quit())); //contextmenu "Quit" for the systray quits Programm
-     connect(checkPassword, SIGNAL(success()), editor, SLOT(show())); //if correct password was entered open editor
+     connect(calendarBox, SIGNAL(starting()), ti, SLOT(stop()));
+     connect(calendarBox, SIGNAL(finishing()), this, SLOT(warnings_on()));
+
+     connect(checkPassword, SIGNAL(success()), this, SLOT(showEditor())); //if correct password was entered open editor
+     connect(checkPassword, SIGNAL(starting()), ti, SLOT(stop()));
+     connect(checkPassword, SIGNAL(finishing()), this, SLOT(warnings_on()));
+
      connect(editor, SIGNAL(saved()), this, SLOT(updateLock()));      //update to see if Lock_all was (de)activated
-     connect(pref, SIGNAL(editConf()), checkPassword, SLOT(show()));  //ask for password when button was pressed at preferences
+     connect(editor, SIGNAL(starting()), ti, SLOT(stop()));
+     connect(editor, SIGNAL(finishing()), this, SLOT(warnings_on()));
+     connect(editor, SIGNAL(saved()), pref, SLOT(loadSettings()));    //if qshutdown.conf was edited and saved, update pref
 }
 
 Gui::~Gui(){ delete font1; delete font2; delete font3; }
 
 void Gui::setInfoText(){ infoBox->setHtml(information); }
 
+void Gui::warnings_on(){
+     if(prefClosed && calendarClosed && infoClosed && passwdClosed && editorClosed && !timeRunning)
+       ti->start();
+}
+
 void Gui::setDate(){ toolButton->setText(setCalendarDate.toString(Qt::SystemLocaleShortDate)); }
 
 void Gui::center(){
@@ -402,7 +425,7 @@ void Gui::updateT(){
        if(i<=86390)
          n = 10; //any number to keep i in check
        if((i==0) || ((i>n) && (i>86390)))
-         finished(); //execute shutdown-type
+         finished_(); //execute shutdown-type
      }
      setWindowTitle(tip1 + tip2);
      TIcon->setToolTip(tip1 + tip2);
@@ -433,7 +456,7 @@ void Gui::set(){
        minim->setFocus();
        minim->setAutoDefault(true);         //minimize-button will accept the return key
      }
-     showMinimized();
+
      if(!lockAll)
        reset_action->setVisible(true);
 }
@@ -461,7 +484,7 @@ void Gui::saveWindowSize(){
      settings.setValue("MainWindowSize/size", size());
 }
 
-void Gui::finished(){
+void Gui::finished_(){
      finishedExecuted = true;
      switch(comboBox->currentIndex()){
        case 0:
@@ -543,7 +566,7 @@ void Gui::loadSettings(){
      QSettings settings(file, QSettings::NativeFormat);
 #endif //Q_OS_WIN32
      if(!settings.isWritable())
-       qCritical() << "W: qshutdown.conf is not writeable!";
+       qCritical() << "W: qshutdown.conf is not writable!";
 
      if(!QFile::exists(file) || !settings.contains("Lock_all"))
        settings.setValue("Lock_all", false);
@@ -558,7 +581,7 @@ void Gui::loadSettings(){
      if(!settings.contains("Hide_at_startup"))
        settings.setValue("Hide_at_startup", false);
      if(!settings.contains("MainWindowSize/size"))
-       settings.setValue("MainWindowSize/size", QSize(430, 325));
+       settings.setValue("MainWindowSize/size", QSize(350, 310));
      if(!settings.contains("Fonts/font_type"))
        settings.setValue("Fonts/font_type", "Times New Roman");
      if(!settings.contains("Fonts/font1"))
@@ -607,7 +630,7 @@ void Gui::loadSettings(){
      if(settings.value("Time/countdown_at_startup").toBool()){
        set();
        if(settings.value("Hide_at_startup").toBool())
-         QTimer::singleShot(1500, this, SLOT(hide()));
+         QTimer::singleShot(2000, this, SLOT(hide()));
      }
 
      if(settings.value("Lock_all").toBool()){
@@ -752,18 +775,20 @@ void Gui::showCalendarBox(){
 }
 
 void Gui::updateLock(){
-    #ifdef Q_OS_WIN32
-       QString file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf");
-    #else //!Q_OS_WIN32
-       QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
-    #endif //Q_OS_WIN32
-       QSettings settings(file, QSettings::NativeFormat);
-       if(settings.value("Lock_all").toBool()){
-         lockAll = true;
-         lockEverything(true);
-       }
-       else{
-         lockAll = false;
-         lockEverything(false);
-       }
+   #ifdef Q_OS_WIN32
+     QString file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf");
+   #else //!Q_OS_WIN32
+     QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
+   #endif //Q_OS_WIN32
+     QSettings settings(file, QSettings::NativeFormat);
+     if(settings.value("Lock_all").toBool()){
+       lockAll = true;
+       lockEverything(true);
+     }
+     else{
+       lockAll = false;
+       lockEverything(false);
+     }
 }
+
+void Gui::showEditor(){ QTimer::singleShot(250, editor, SLOT(show())); } //using singleShot because of focus problems...
