@@ -78,6 +78,7 @@ class Gui : public QWidget, public Ui::Gui {
      // defining signals and slots
  
     private slots:
+     void warnings_on();
      void iconActivated(QSystemTrayIcon::ActivationReason reason);
      void showW();
      void set();
@@ -87,7 +88,7 @@ class Gui : public QWidget, public Ui::Gui {
      void power(QAction *action);
      void saveWindowSize();
      void reset();
-     void finished();
+     void finished_();
      void beforeQuit();
      void setInfoText();
      void getFonts();
@@ -95,6 +96,7 @@ class Gui : public QWidget, public Ui::Gui {
      void setDate();
      void lockEverything(bool actual);
      void updateLock();
+     void showEditor();
     public slots:
      Q_SCRIPTABLE void showRunningProgram();
     protected:
