@@ -17,7 +17,8 @@
 
 #include "info.h"
 
-extern bool timeRunning; //varibale declared in gui.cpp
+extern bool infoClosed;  //varibale declared in gui.cpp
+extern bool timeRunning; // ""
 
 Info::Info(QWidget *parent): QTextEdit(parent){
      setWindowFlags(Qt::WindowStaysOnTopHint | Qt::Window);
@@ -29,12 +30,15 @@ Info::Info(QWidget *parent): QTextEdit(parent){
 Info::~Info(){ }
 
 void Info::showEvent(QShowEvent* show_){
+     infoClosed = false;
      starting();
      QTextEdit::showEvent(show_);
 }
 
-void Info::closeEvent(QCloseEvent* window_close){
-     if(!timeRunning)
+void Info::closeEvent(QCloseEvent* close_){
+     if(!timeRunning){
+       infoClosed = true;
        finishing();
-     QTextEdit::closeEvent(window_close);
+     }
+     QTextEdit::closeEvent(close_);
 }
