@@ -32,7 +32,7 @@ class Info : public QTextEdit{
 
     protected:
      virtual void showEvent(QShowEvent* show_);
-     virtual void closeEvent(QCloseEvent* window_close);
+     virtual void closeEvent(QCloseEvent* close_);
 };
 
 #endif //INFO_H
