@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2009 2010  Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2009 2010 2011 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,14 +50,14 @@ int main(int argc, char *argv[]){
        "username or %groupname.<br/><br/>The maximum Number of countdown_minutes is "
        "1440 (24 hours).<br/>The configurationfile (and logfile) is located at "
        "<i>~/.qshutdown/</i> (under Linux/Unix).<br/><br/><b>For admins:</b><br/>If you want "
-       "qshutdown to run with \"parental lock\", you can do "
-       "\"sudo cp /usr/share/qshutdown/root_autostart/qshutdown.desktop /etc/xdg/autostart/\" "
+       "qshutdown to run with \"parental lock\" for every user, you can do "
+       "\"sudo cp /usr/share/qshutdown/autostart/99qshutdown /etc/X11/Xsession.d/\" "
        "and set the option Lock_all in /root/.qshutdown/qshutdown.conf to true. Note that "
-       "qshutdown has to run one time to generate the qshutdown.conf. Furthermore there is a "
+       "qshutdown has to start once to generate the qshutdown.conf. Furthermore there is a "
        "need to add the following line to the sudoers (as above):"
-       "<pre>* ALL = NOPASSWD:/usr/bin/qshutdown_script</pre>To return to user mode do"
-       " \"sudo cp /usr/share/applications/qshutdown.desktop /etc/xdg/autostart/\"."
-       "<br/>With shortcut \"Shift + E\" you can edit the .conf files at any time."));
+       "<pre>* ALL = NOPASSWD:/usr/bin/qshutdown</pre><br/>If you should ever forget "
+       "your set password, just remove the whole line starting with \"Password\" manually from "
+       "the qshutdown.conf."));
      QTextDocumentFragment infoDoc;
      infoDoc = QTextDocumentFragment::fromHtml(infoStr);
      QString info = infoDoc.toPlainText();
