@@ -18,6 +18,9 @@
 #include "passwd.h"
 #include "ch_passwd.h"
 
+extern bool passwdClosed; //varibale declared in gui.cpp
+extern bool timeRunning;  // ""
+
 PassWord::PassWord(QWidget *parent): QDialog(parent){
 
 	setupUi(this);
@@ -48,6 +51,7 @@ PassWord::PassWord(QWidget *parent): QDialog(parent){
      connect(buttonBox, SIGNAL(accepted()), this, SLOT(checkPW()));
      connect(changePasswdButton, SIGNAL(clicked(bool)), chPW, SLOT(show()));
      connect(this, SIGNAL(rejected()), passwdLineEdit, SLOT(clear()));
+     connect(this, SIGNAL(rejected()), this, SLOT(close()));
      connect(chPW, SIGNAL(updatePasswordGui()), this, SLOT(update()));
 }
 
@@ -58,8 +62,8 @@ void PassWord::checkPW(){
          QCryptographicHash::hash(passwdLineEdit->text().toUtf8(), QCryptographicHash::Sha1)){
                                    //check if the entered password matches the saved one
        success();
-       accept();
        passwdLineEdit->clear();
+       close();
      }
      else
        msgBox->exec();
@@ -71,3 +75,17 @@ void PassWord::update(){
        changePasswdButton->setText(tr("&Change password"));
      }
 }
+
+void PassWord::showEvent(QShowEvent* show_){
+     passwdClosed = false;
+     starting();
+     QDialog::showEvent(show_);
+}
+
+void PassWord::closeEvent(QCloseEvent* close_){
+     if(!timeRunning){
+       passwdClosed = true;
+       finishing();
+     }
+     QDialog::closeEvent(close_);
+}
