@@ -17,7 +17,8 @@
 
 #include "preferences.h"
 
-extern bool timeRunning; //varibale declared in gui.cpp
+extern bool prefClosed;   //varibale declared in gui.cpp
+extern bool timeRunning;  // ""
 extern bool lockMyScreen; // ""
 QString fonts = "Times New Roman";
 int fontS1 = 13;
@@ -47,7 +48,7 @@ Preferences::Preferences(QWidget *parent): QDialog(parent){
      msgBox->setWindowTitle("Error");
      msgBox->setIcon(QMessageBox::Warning);
      msgBox->setWindowFlags(Qt::WindowStaysOnTopHint | Qt::Window);
-     msgBox->setInformativeText(tr("The File \"") + file + tr("\" is not writeable!\n"
+     msgBox->setInformativeText(tr("The File \"") + file + tr("\" is not writable!\n"
      "Maybe you just don't have the permissions to do so."));
 
      connect(buttonBox, SIGNAL(accepted()), this, SLOT(saveToConfFile()));
@@ -58,12 +59,14 @@ Preferences::Preferences(QWidget *parent): QDialog(parent){
      connect(fontComboBox, SIGNAL(currentIndexChanged(QString)), this, SLOT(fontChanged(QString)));
      connect(buttonBox, SIGNAL(rejected()), this, SLOT(resetFont()));
      connect(lockS, SIGNAL(toggled(bool)), this, SLOT(lockScreen()));
-     connect(confEditButton, SIGNAL(clicked(bool)), this, SLOT(sendEditSignal()));
+     connect(confEditButton, SIGNAL(clicked(bool)), this, SIGNAL(editConf()));
+     connect(this, SIGNAL(rejected()), this, SLOT(close()));
 }
 
 Preferences::~Preferences(){ delete settings; }
 
 void Preferences::showEvent(QShowEvent* show_pref){
+     prefClosed = false;
      starting(); //sends SIGNAL starting()
      loadSettings();
      if(!settings->isWritable()){
@@ -93,6 +96,8 @@ void Preferences::loadSettings(){
      log->setChecked(settings->value("Logfile/logging").toBool());
      lockS->setChecked(settings->value("Lock_screen").toBool());
      autostart->setChecked(settings->value("Autostart").toBool());
+
+     autostartFile(); //to create or to delete the autostart file
 }
 
 void Preferences::saveToConfFile(){
@@ -116,7 +121,6 @@ void Preferences::saveToConfFile(){
        settings->setValue("Lock_screen", lockS->isChecked());
        settings->setValue("Autostart", autostart->isChecked());
      }
-     autostartFile();
 }
 
 void Preferences::resetSettings(){
@@ -148,8 +152,10 @@ void Preferences::lockScreen(){
 }
 
 void Preferences::closeEvent(QCloseEvent* window_close){
-     if(!timeRunning)
+     if(!timeRunning){
+       prefClosed = true;
        finishing(); //sends SIGNAL finishing()
+     }
      if(settings->isWritable())
        settings->setValue("PrefWindowSize/size", size());
 
@@ -172,12 +178,10 @@ void Preferences::resetFont(){
      changeFont();
 }
 
-void Preferences::sendEditSignal(){ editConf(); }
-
 void Preferences::autostartFile(){
     #ifndef Q_OS_WIN32
      QFile autostartFile(QDir::homePath() + "/.config/autostart/qshutdown.desktop");
-     if(autostart->isChecked() && !autostartFile.exists()){
+     if(settings->value("Autostart").toBool() && !autostartFile.exists()){
        if(!QDir(QDir::homePath() + "/.config/autostart").exists()){
          QDir dir(QDir::homePath() + "/.config/autostart");
          dir.mkdir(QDir::homePath() + "/.config/autostart");
@@ -193,7 +197,7 @@ void Preferences::autostartFile(){
          out << autostartContent;
          autostartFile.close();
      }
-     if(autostartFile.exists() && !autostart->isChecked())
+     if(autostartFile.exists() && !settings->value("Autostart").toBool())
        autostartFile.remove();
     #endif
 }
